@@ -1,15 +1,12 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from sql import Table
-
-from trytond import backend
-from trytond.model import ModelView, ModelSQL, fields, Unique
-from trytond.transaction import Transaction
+from trytond.model import DeactivableMixin, ModelSQL, ModelView, Unique, fields
 from trytond.pool import Pool
 from trytond.pyson import Eval
+from trytond.transaction import Transaction
 
 
-class Journal(ModelSQL, ModelView):
+class Journal(DeactivableMixin, ModelSQL, ModelView):
     'Statement Journal'
     __name__ = 'account.statement.journal'
     name = fields.Char('Name', required=True)
@@ -19,17 +16,16 @@ class Journal(ModelSQL, ModelView):
         context={
             'company': Eval('company', -1),
             },
-        depends=['company'])
+        depends={'company'})
     currency = fields.Many2One('currency.currency', 'Currency', required=True)
-    company = fields.Many2One('company.company', 'Company', required=True,
-            select=True)
+    company = fields.Many2One('company.company', "Company", required=True)
     company_party = fields.Function(
         fields.Many2One(
             'party.party', "Company Party",
             context={
                 'company': Eval('company', -1),
                 },
-            depends=['company']),
+            depends={'company'}),
         'on_change_with_company_party')
     validation = fields.Selection([
             ('balance', 'Balance'),
@@ -41,16 +37,14 @@ class Journal(ModelSQL, ModelView):
         domain=[
             ('owners.id', '=', Eval('company_party', -1)),
             ('currency', '=', Eval('currency', -1)),
-            ],
-        depends=['company_party', 'currency'])
+            ])
     account = fields.Many2One('account.account', "Account", required=True,
         domain=[
             ('type', '!=', None),
             ('closed', '!=', True),
             ('company', '=', Eval('company')),
             ('party_required', '=', False),
-            ],
-        depends=['company'])
+            ])
 
     @classmethod
     def __setup__(cls):
@@ -63,26 +57,6 @@ class Journal(ModelSQL, ModelView):
                 'account_statement.msg_journal_bank_account_unique'),
             ]
 
-    @classmethod
-    def __register__(cls, module_name):
-        cursor = Transaction().connection.cursor()
-        table = backend.TableHandler(cls, module_name)
-        sql_table = cls.__table__()
-        journal_account = Table('account_journal_account')
-
-        created_account = not table.column_exist('account')
-
-        super(Journal, cls).__register__(module_name)
-
-        # Migration from 4.8: new account field
-        if created_account and table.table_exist('account_journal_account'):
-            value = journal_account.select(journal_account.credit_account,
-                where=((journal_account.journal == sql_table.journal)
-                    & (journal_account.credit_account
-                        == journal_account.debit_account)))
-            # Don't use UPDATE FROM because SQLite does not support it.
-            cursor.execute(*sql_table.update([sql_table.account], [value]))
-
     @staticmethod
     def default_currency():
         if Transaction().context.get('company'):
@@ -96,8 +70,7 @@ class Journal(ModelSQL, ModelView):
 
     @fields.depends('company')
     def on_change_with_company_party(self, name=None):
-        if self.company:
-            return self.company.party.id
+        return self.company.party if self.company else None
 
     @staticmethod
     def default_validation():
